@@ -85,9 +85,8 @@ def WriteReformattedCode(filename, reformatted_code, in_place, encoding):
     encoding: (unicode) The encoding of the file.
   """
   if in_place:
-    with py3compat.open_with_encoding(filename,
-                                      mode='w',
-                                      encoding=encoding) as fd:
+    with py3compat.open_with_encoding(
+        filename, mode='w', encoding=encoding) as fd:
       fd.write(reformatted_code)
   else:
     py3compat.EncodeAndWriteToStdout(reformatted_code, encoding)
@@ -100,10 +99,10 @@ def _FindPythonFiles(filenames, recursive, exclude):
     if os.path.isdir(filename):
       if recursive:
         # TODO(morbo): Look into a version of os.walk that can handle recursion.
-        python_files.extend(os.path.join(dirpath, f)
-                            for dirpath, _, filelist in os.walk(filename)
-                            for f in filelist
-                            if IsPythonFile(os.path.join(dirpath, f)))
+        python_files.extend(
+            os.path.join(dirpath, f)
+            for dirpath, _, filelist in os.walk(filename) for f in filelist
+            if IsPythonFile(os.path.join(dirpath, f)))
       else:
         raise errors.YapfError(
             "directory specified without '--recursive' flag: %s" % filename)
@@ -138,9 +137,8 @@ def IsPythonFile(filename):
     return False
 
   try:
-    with py3compat.open_with_encoding(filename,
-                                      mode='r',
-                                      encoding=encoding) as fd:
+    with py3compat.open_with_encoding(
+        filename, mode='r', encoding=encoding) as fd:
       first_line = fd.readlines()[0]
   except (IOError, IndexError):
     return False
